/*
 * $Id: //depot/prod/newport_news/main/modules/jndmp/src/main/java/com/netapp/ndmp/NdmpMessageException.java#2 $
 *
 * Copyright (c) 2008 Network Appliance, Inc.
 * All rights reserved.
 */

package com.netapp.ndmp;

import java.util.Map;

import com.google.common.base.Objects;
import com.google.common.collect.ImmutableMap;

import com.netapp.ndmp.rpcgen.ndmp_error;

public class NdmpMessageException extends NdmpException {

    private static final Map<Integer, String> ERROR_MESSAGE_MAP;

    private final int errorCode;
    private int messageCode;

    public NdmpMessageException(int messageCode, int errorCode) {
        super("Error code in NDMP message: "
            + Objects.firstNonNull(ERROR_MESSAGE_MAP.get(errorCode), (Integer.toHexString(errorCode) + "h")));
        this.messageCode = messageCode;
        this.errorCode = errorCode;
    }

    public NdmpMessageException(int errorCode) {

        this(0, errorCode);
    }

    public void setMessageCode(int messageCode) {

        this.messageCode = messageCode;
    }

    public int getMessageCode() {

        return messageCode;
    }

    public int getErrorCode() {

        return errorCode;
    }

    static {
        ERROR_MESSAGE_MAP = ImmutableMap.<Integer, String>builder()
            .put(ndmp_error.NDMP_NO_ERR, "NDMP_NO_ERR")
            .put(ndmp_error.NDMP_NOT_SUPPORTED_ERR, ".NDMP_NOT_SUPPORTED_ERR")
            .put(ndmp_error.NDMP_DEVICE_BUSY_ERR, "NDMP_DEVICE_BUSY_ERR")
            .put(ndmp_error.NDMP_DEVICE_OPENED_ERR, "NDMP_DEVICE_OPENED_ERR")
            .put(ndmp_error.NDMP_NOT_AUTHORIZED_ERR, "NDMP_NOT_AUTHORIZED_ERR")
            .put(ndmp_error.NDMP_PERMISSION_ERR, "NDMP_PERMISSION_ERR")
            .put(ndmp_error.NDMP_DEV_NOT_OPEN_ERR, "NDMP_DEV_NOT_OPEN_ERR")
            .put(ndmp_error.NDMP_IO_ERR, "NDMP_IO_ERR")
            .put(ndmp_error.NDMP_TIMEOUT_ERR, "NDMP_TIMEOUT_ERR")
            .put(ndmp_error.NDMP_ILLEGAL_ARGS_ERR, "NDMP_ILLEGAL_ARGS_ERR")
            .put(ndmp_error.NDMP_NO_TAPE_LOADED_ERR, "NDMP_NO_TAPE_LOADED_ERR")
            .put(ndmp_error.NDMP_WRITE_PROTECT_ERR, "NDMP_WRITE_PROTECT_ERR")
            .put(ndmp_error.NDMP_EOF_ERR, "NDMP_EOF_ERR")
            .put(ndmp_error.NDMP_EOM_ERR, "NDMP_EOM_ERR")
            .put(ndmp_error.NDMP_FILE_NOT_FOUND_ERR, "NDMP_FILE_NOT_FOUND_ERR")
            .put(ndmp_error.NDMP_BAD_FILE_ERR, "NDMP_BAD_FILE_ERR")
            .put(ndmp_error.NDMP_NO_DEVICE_ERR, "NDMP_NO_DEVICE_ERR")
            .put(ndmp_error.NDMP_NO_BUS_ERR, "NDMP_NO_BUS_ERR")
            .put(ndmp_error.NDMP_XDR_DECODE_ERR, "NDMP_XDR_DECODE_ERR")
            .put(ndmp_error.NDMP_ILLEGAL_STATE_ERR, "NDMP_ILLEGAL_STATE_ERR")
            .put(ndmp_error.NDMP_UNDEFINED_ERR, "NDMP_UNDEFINED_ERR")
            .put(ndmp_error.NDMP_XDR_ENCODE_ERR, "NDMP_XDR_ENCODE_ERR")
            .put(ndmp_error.NDMP_NO_MEM_ERR, "NDMP_NO_MEM_ERR")
            .put(ndmp_error.NDMP_CONNECT_ERR, "NDMP_CONNECT_ERR")
            .put(ndmp_error.NDMP_SEQUENCE_NUM_ERR, "NDMP_SEQUENCE_NUM_ERR")
            .put(ndmp_error.NDMP_READ_IN_PROGRESS_ERR, "NDMP_READ_IN_PROGRESS_ERR")
            .put(ndmp_error.NDMP_PRECONDITION_ERR, "NDMP_PRECONDITION_ERR")
            .put(ndmp_error.NDMP_CLASS_NOT_SUPPORTED_ERR, "NDMP_CLASS_NOT_SUPPORTED_ERR")
            .put(ndmp_error.NDMP_VERSION_NOT_SUPPORTED_ERR, "NDMP_VERSION_NOT_SUPPORTED_ERR")
            .build();
    }
}
