/*
 * $Id: //depot/prod/newport_news/main/modules/jndmp/src/main/java/com/netapp/ndmp/NdmpUtil.java#2 $
 *
 * Copyright (c) 2010 Network Appliance, Inc.
 * All rights reserved.
 */

package com.netapp.ndmp;

import java.lang.reflect.Array;
import java.lang.reflect.Field;

import org.acplt.oncrpc.XdrAble;

public class NdmpUtil {

    private NdmpUtil() {
        // prevent instantiation
    }

    private static void buildXml(String name, Object content, StringBuilder buf, int depth, int maxDepth)
    {
        if (0 < depth) {
            /*
             *  Add newline/indentation
             */
            buf.append('\n');
            for (int i = 0; i < depth; i++) {
                buf.append("  ");
            }
        }

        buf.append('<');
        buf.append(name);
        if (null == content) {
            buf.append("/>");
            return;
        }
        buf.append('>');

        if (!(content instanceof XdrAble || content.getClass().isArray())) {
            buf.append(content.toString());
        } else if (depth < maxDepth) {
            if (content.getClass().isArray()) {
                for (int i = 0; i < Array.getLength(content); i++) {
                    Object obj = Array.get(content, i);
                    if (obj instanceof Byte) {
                        buildXml("ByteArray", null, buf, depth + 1, maxDepth);
                        break;
                    }
                    String name2 = obj.getClass().getSimpleName();
                    buildXml(name2, obj, buf, depth + 1, maxDepth);
                }
            } else {
                for (Field field : content.getClass().getFields()) {
                    try {
                        Object obj = field.get(content);
                        String name2 = field.getName();
                        buildXml(name2, obj, buf, depth + 1, maxDepth);
                    } catch (Exception e) {
                        //Swallow exception, was in original implementation from Ben
                    }
                }
            }
            /*
             *  Add newline/indentation
             */
            buf.append('\n');
            for (int i = 0; i < depth; i++) {
                buf.append("  ");
            }
        } else {
            buf.append("...");
        }

        buf.append("</");
        buf.append(name);
        buf.append('>');
    }

    public static String getXml(XdrAble xdr) {
        if (null == xdr) {
            return "null";
        }
        StringBuilder buf = new StringBuilder();
        buildXml(xdr.getClass().getSimpleName(), xdr, buf, 0, Integer.MAX_VALUE);
        return buf.toString();
    }
}
